cumulusci.tasks.release\_notes.tests package
============================================

Submodules
----------


.. automodule:: cumulusci.tasks.release_notes.tests.test_generator
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.release_notes.tests.test_parser
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.release_notes.tests.test_provider
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.release_notes.tests.test_task
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.release_notes.tests.utils
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.release_notes.tests
   :members:
   :undoc-members:
   :show-inheritance:
